Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(14)

Unified Diff: include/gpu/GrContext.h

Issue 716143004: Replace GrResourceCache with GrResourceCache2. (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: fix asserts Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « include/gpu/GrConfig.h ('k') | include/gpu/GrGpuResource.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/gpu/GrContext.h
diff --git a/include/gpu/GrContext.h b/include/gpu/GrContext.h
index 97acda1e795a4cc540525d65c805b5d3fd18c3c3..3dbf7b3ea88d7080d5f96aef7dbce01f768a9e31 100644
--- a/include/gpu/GrContext.h
+++ b/include/gpu/GrContext.h
@@ -33,7 +33,6 @@ class GrOvalRenderer;
class GrPath;
class GrPathRenderer;
class GrResourceEntry;
-class GrResourceCache;
class GrResourceCache2;
class GrStencilBuffer;
class GrTestTarget;
@@ -883,7 +882,6 @@ public:
GrDrawTarget* getTextTarget();
const GrIndexBuffer* getQuadIndexBuffer() const;
GrAARectRenderer* getAARectRenderer() { return fAARectRenderer; }
- GrResourceCache* getResourceCache() { return fResourceCache; }
GrResourceCache2* getResourceCache2() { return fResourceCache2; }
// Called by tests that draw directly to the context via GrDrawTarget
@@ -948,7 +946,6 @@ private:
const GrClipData* fClip; // TODO: make this ref counted
GrDrawState* fDrawState;
- GrResourceCache* fResourceCache;
GrResourceCache2* fResourceCache2;
GrFontCache* fFontCache;
SkAutoTDelete<GrLayerCache> fLayerCache;
@@ -962,7 +959,6 @@ private:
// Set by OverbudgetCB() to request that GrContext flush before exiting a draw.
bool fFlushToReduceCacheSize;
-
GrAARectRenderer* fAARectRenderer;
GrOvalRenderer* fOvalRenderer;
@@ -1003,8 +999,6 @@ private:
size_t rowBytes,
bool filter);
- GrTexture* createNewScratchTexture(const GrSurfaceDesc& desc);
-
/**
* These functions create premul <-> unpremul effects if it is possible to generate a pair
* of effects that make a readToUPM->writeToPM->readToUPM cycle invariant. Otherwise, they
@@ -1015,9 +1009,9 @@ private:
/**
* This callback allows the resource cache to callback into the GrContext
* when the cache is still overbudget after a purge.
*/
- static bool OverbudgetCB(void* data);
+ static void OverBudgetCB(void* data);
typedef SkRefCnt INHERITED;
};
« no previous file with comments | « include/gpu/GrConfig.h ('k') | include/gpu/GrGpuResource.h » ('j') | no next file with comments »
@@ -1015,9 +1009,9 @@ private:
/**
* This callback allows the resource cache to callback into the GrContext
- * when the cache is still overbudget after a purge.
+ * when the cache is still over budget after a purge.
*/

Powered by Google App Engine
This is Rietveld 408576698